@@ -1,18 +1,23 @@
-import re
+from __future__ import annotations
+
 import base64
+import datetime
 import hashlib
 import hmac
 import json
-import datetime
+import re
+from typing import Any
 from urllib import parse
-from typing import Any, Dict, List, Optional, Union
-from meilisearch.index import Index
-from meilisearch.config import Config
-from meilisearch.task import get_task, get_tasks, wait_for_task
-from meilisearch._httprequests import HttpRequests
-from meilisearch.errors import MeiliSearchError
 
-class Client():
+from meilisearch._httprequests import HttpRequests
+from meilisearch.config import Config
+from meilisearch.errors import MeiliSearchError
+from meilisearch.index import Index
+from meilisearch.models.task import TaskInfo
+from meilisearch.task import cancel_tasks, delete_tasks, get_task, get_tasks, wait_for_task
+
+
+class Client:
     """
     A client for the Meilisearch API
 
@@ -20,9 +25,7 @@ class Client():
     Meilisearch and its permissions.
     """
 
-    def __init__(
-        self, url: str, api_key: Optional[str] = None, timeout: Optional[int] = None
-    ) -> None:
+    def __init__(self, url: str, api_key: str | None = None, timeout: int | None = None) -> None:
         """
         Parameters
         ----------
@@ -35,7 +38,7 @@ class Client():
 
         self.http = HttpRequests(self.config)
 
-    def create_index(self, uid: str, options: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
+    def create_index(self, uid: str, options: dict[str, Any] | None = None) -> dict[str, Any]:
         """Create an index.
 
         Parameters
@@ -58,7 +61,7 @@ class Client():
         """
         return Index.create(self.config, uid, options)
 
-    def delete_index(self, uid: str) -> Dict[str, Any]:
+    def delete_index(self, uid: str) -> dict[str, Any]:
         """Deletes an index
 
         Parameters
@@ -78,9 +81,9 @@ class Client():
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
 
-        return self.http.delete(f'{self.config.paths.index}/{uid}')
+        return self.http.delete(f"{self.config.paths.index}/{uid}")
 
-    def get_indexes(self, parameters: Optional[Dict[str, Any]] = None) -> Dict[str, List[Index]]:
+    def get_indexes(self, parameters: dict[str, Any] | None = None) -> dict[str, list[Index]]:
         """Get all indexes.
 
         Parameters
@@ -100,22 +103,20 @@ class Client():
         """
         if parameters is None:
             parameters = {}
-        response = self.http.get(
-            f'{self.config.paths.index}?{parse.urlencode(parameters)}'
-        )
-        response['results'] = [
-                Index(
-                    self.config,
-                    index["uid"],
-                    index["primaryKey"],
-                    index["createdAt"],
-                    index["updatedAt"],
-                )
-                for index in response['results']
-            ]
+        response = self.http.get(f"{self.config.paths.index}?{parse.urlencode(parameters)}")
+        response["results"] = [
+            Index(
+                self.config,
+                index["uid"],
+                index["primaryKey"],
+                index["createdAt"],
+                index["updatedAt"],
+            )
+            for index in response["results"]
+        ]
         return response
 
-    def get_raw_indexes(self, parameters: Optional[Dict[str, Any]] = None) -> List[Dict[str, Any]]:
+    def get_raw_indexes(self, parameters: dict[str, Any] | None = None) -> list[dict[str, Any]]:
         """Get all indexes in dictionary format.
 
         Parameters
@@ -135,9 +136,7 @@ class Client():
         """
         if parameters is None:
             parameters = {}
-        return self.http.get(
-            f'{self.config.paths.index}?{parse.urlencode(parameters)}'
-        )
+        return self.http.get(f"{self.config.paths.index}?{parse.urlencode(parameters)}")
 
     def get_index(self, uid: str) -> Index:
         """Get the index.
@@ -160,7 +159,7 @@ class Client():
         """
         return Index(self.config, uid).fetch_info()
 
-    def get_raw_index(self, uid: str) -> Dict[str, Any]:
+    def get_raw_index(self, uid: str) -> dict[str, Any]:
         """Get the index as a dictionary.
         This index should already exist.
 
@@ -179,7 +178,7 @@ class Client():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.get(f'{self.config.paths.index}/{uid}')
+        return self.http.get(f"{self.config.paths.index}/{uid}")
 
     def index(self, uid: str) -> Index:
         """Create a local reference to an index identified by UID, without doing an HTTP call.
@@ -197,9 +196,9 @@ class Client():
         """
         if uid is not None:
             return Index(self.config, uid=uid)
-        raise Exception('The index UID should not be None')
+        raise Exception("The index UID should not be None")
 
-    def get_all_stats(self) -> Dict[str, Any]:
+    def get_all_stats(self) -> dict[str, Any]:
         """Get all stats of Meilisearch
 
         Get information about database size and all indexes
@@ -217,7 +216,7 @@ class Client():
         """
         return self.http.get(self.config.paths.stat)
 
-    def health(self) -> Dict[str, str]:
+    def health(self) -> dict[str, str]:
         """Get health of the Meilisearch server.
 
         Returns
@@ -233,15 +232,14 @@ class Client():
         return self.http.get(self.config.paths.health)
 
     def is_healthy(self) -> bool:
-        """Get health of the Meilisearch server.
-        """
+        """Get health of the Meilisearch server."""
         try:
             self.health()
         except MeiliSearchError:
             return False
         return True
 
-    def get_key(self, key_or_uid: str) -> Dict[str, Any]:
+    def get_key(self, key_or_uid: str) -> dict[str, Any]:
         """Gets information about a specific API key.
 
         Parameters
@@ -260,9 +258,9 @@ class Client():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.get(f'{self.config.paths.keys}/{key_or_uid}')
+        return self.http.get(f"{self.config.paths.keys}/{key_or_uid}")
 
-    def get_keys(self, parameters: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
+    def get_keys(self, parameters: dict[str, Any] | None = None) -> dict[str, Any]:
         """Gets the Meilisearch API keys.
 
         Parameters
@@ -283,14 +281,9 @@ class Client():
         """
         if parameters is None:
             parameters = {}
-        return self.http.get(
-            f'{self.config.paths.keys}?{parse.urlencode(parameters)}'
-        )
+        return self.http.get(f"{self.config.paths.keys}?{parse.urlencode(parameters)}")
 
-    def create_key(
-        self,
-        options: Dict[str, Any]
-    ) -> Dict[str, Any]:
+    def create_key(self, options: dict[str, Any]) -> dict[str, Any]:
         """Creates a new API key.
 
         Parameters
@@ -313,17 +306,12 @@ class Client():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(f'{self.config.paths.keys}', options)
+        return self.http.post(f"{self.config.paths.keys}", options)
 
-    def update_key(
-        self,
-        key_or_uid: str,
-        options: Dict[str, Any]
-    ) -> Dict[str, Any]:
+    def update_key(self, key_or_uid: str, options: dict[str, Any]) -> dict[str, Any]:
         """Update an API key.
 
         Parameters
-
         ----------
         key:
             The key or the uid of the key for which to update the information.
@@ -342,10 +330,10 @@ class Client():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        url = f'{self.config.paths.keys}/{key_or_uid}'
+        url = f"{self.config.paths.keys}/{key_or_uid}"
         return self.http.patch(url, options)
 
-    def delete_key(self, key_or_uid: str) -> Dict[str, int]:
+    def delete_key(self, key_or_uid: str) -> dict[str, int]:
         """Deletes an API key.
 
         Parameters
@@ -364,9 +352,9 @@ class Client():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.delete(f'{self.config.paths.keys}/{key_or_uid}')
+        return self.http.delete(f"{self.config.paths.keys}/{key_or_uid}")
 
-    def get_version(self) -> Dict[str, str]:
+    def get_version(self) -> dict[str, str]:
         """Get version Meilisearch
 
         Returns
@@ -381,7 +369,7 @@ class Client():
         """
         return self.http.get(self.config.paths.version)
 
-    def version(self) -> Dict[str, str]:
+    def version(self) -> dict[str, str]:
         """Alias for get_version
 
         Returns
@@ -396,7 +384,7 @@ class Client():
         """
         return self.get_version()
 
-    def create_dump(self) -> Dict[str, str]:
+    def create_dump(self) -> dict[str, str]:
         """Trigger the creation of a Meilisearch dump.
 
         Returns
@@ -412,14 +400,36 @@ class Client():
         """
         return self.http.post(self.config.paths.dumps)
 
-    def get_tasks(self, parameters: Optional[Dict[str, Any]] = None) -> Dict[str, List[Dict[str, Any]]]:
+    def swap_indexes(self, parameters: list[dict[str, list[str]]]) -> TaskInfo:
+        """Swap two indexes.
+
+        Parameters
+        ----------
+        indexes:
+            List of indexes to swap (ex: [{"indexes": ["indexA", "indexB"]}).
+
+        Returns
+        -------
+        task_info:
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return TaskInfo(**self.http.post(self.config.paths.swap, parameters))
+
+    def get_tasks(
+        self, parameters: dict[str, Any] | None = None
+    ) -> dict[str, list[dict[str, Any]]]:
         """Get all tasks.
 
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get tasks route: https://docs.meilisearch.com/reference/api/tasks.html#get-all-tasks.
-            `indexUid` should be set as a List.
+            parameters accepted by the get tasks route: https://docs.meilisearch.com/reference/api/tasks.html#get-tasks.
 
         Returns
         -------
@@ -433,7 +443,7 @@ class Client():
         """
         return get_tasks(self.config, parameters=parameters)
 
-    def get_task(self, uid: int) -> Dict[str, Any]:
+    def get_task(self, uid: int) -> dict[str, Any]:
         """Get one task.
 
         Parameters
@@ -453,11 +463,52 @@ class Client():
         """
         return get_task(self.config, uid)
 
+    def cancel_tasks(self, parameters: dict[str, Any]) -> TaskInfo:
+        """Cancel a list of enqueued or processing tasks.
+
+        Parameters
+        ----------
+        parameters (optional):
+            parameters accepted by the cancel tasks route:https://docs.meilisearch.com/reference/api/tasks.html#cancel-tasks.
+
+        Returns
+        -------
+        task_info:
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return cancel_tasks(self.config, parameters=parameters)
+
+    def delete_tasks(self, parameters: dict[str, Any]) -> TaskInfo:
+        """Delete a list of finished tasks.
+
+        Parameters
+        ----------
+        parameters (optional):
+            parameters accepted by the delete tasks route:https://docs.meilisearch.com/reference/api/tasks.html#delete-task.
+        Returns
+        -------
+        task_info:
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return delete_tasks(self.config, parameters=parameters)
+
     def wait_for_task(
-        self, uid: int,
+        self,
+        uid: int,
         timeout_in_ms: int = 5000,
         interval_in_ms: int = 50,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Wait until Meilisearch processes a task until it fails or succeeds.
 
         Parameters
@@ -484,10 +535,10 @@ class Client():
     def generate_tenant_token(
         self,
         api_key_uid: str,
-        search_rules: Union[Dict[str, Any], List[str]],
+        search_rules: dict[str, Any] | list[str],
         *,
-        expires_at: Optional[datetime.datetime] = None,
-        api_key: Optional[str] = None
+        expires_at: datetime.datetime | None = None,
+        api_key: str | None = None,
     ) -> str:
         """Generate a JWT token for the use of multitenancy.
 
@@ -512,33 +563,32 @@ class Client():
            `exp` must be a `datetime` in the future. It's not possible to create a token from the master key.
         """
         # Validate all fields
-        if api_key == '' or api_key is None and self.config.api_key is None:
-            raise Exception('An api key is required in the client or should be passed as an argument.')
-        if api_key_uid == '' or api_key_uid is None or self._valid_uuid(api_key_uid) is False:
-            raise Exception('An uid is required and must comply to the uuid4 format.')
-        if not search_rules or search_rules == ['']:
-            raise Exception('The search_rules field is mandatory and should be defined.')
+        if api_key == "" or api_key is None and self.config.api_key is None:
+            raise Exception(
+                "An api key is required in the client or should be passed as an argument."
+            )
+        if api_key_uid == "" or api_key_uid is None or self._valid_uuid(api_key_uid) is False:
+            raise Exception("An uid is required and must comply to the uuid4 format.")
+        if not search_rules or search_rules == [""]:
+            raise Exception("The search_rules field is mandatory and should be defined.")
         if expires_at and expires_at < datetime.datetime.utcnow():
-            raise Exception('The date expires_at should be in the future.')
+            raise Exception("The date expires_at should be in the future.")
 
         # Standard JWT header for encryption with SHA256/HS256 algorithm
-        header = {
-            "typ": "JWT",
-            "alg": "HS256"
-        }
+        header = {"typ": "JWT", "alg": "HS256"}
 
         api_key = str(self.config.api_key) if api_key is None else api_key
 
         # Add the required fields to the payload
         payload = {
-            'apiKeyUid': api_key_uid,
-            'searchRules': search_rules,
-            'exp': int(datetime.datetime.timestamp(expires_at)) if expires_at is not None else None
+            "apiKeyUid": api_key_uid,
+            "searchRules": search_rules,
+            "exp": int(datetime.datetime.timestamp(expires_at)) if expires_at is not None else None,
         }
 
         # Serialize the header and the payload
-        json_header = json.dumps(header, separators=(",",":")).encode()
-        json_payload = json.dumps(payload, separators=(",",":")).encode()
+        json_header = json.dumps(header, separators=(",", ":")).encode()
+        json_payload = json.dumps(payload, separators=(",", ":")).encode()
 
         # Encode the header and the payload to Base64Url String
         header_encode = self._base64url_encode(json_header)
@@ -546,22 +596,25 @@ class Client():
 
         secret_encoded = api_key.encode()
         # Create Signature Hash
-        signature = hmac.new(secret_encoded, (header_encode + "." + payload_encode).encode(), hashlib.sha256).digest()
+        signature = hmac.new(
+            secret_encoded,
+            (header_encode + "." + payload_encode).encode(),
+            hashlib.sha256,
+        ).digest()
         # Create JWT
-        jwt_token = header_encode + '.' + payload_encode + '.' + self._base64url_encode(signature)
+        jwt_token = header_encode + "." + payload_encode + "." + self._base64url_encode(signature)
 
         return jwt_token
 
     @staticmethod
-    def _base64url_encode(
-        data: bytes
-    ) -> str:
-        return base64.urlsafe_b64encode(data).decode('utf-8').replace('=','')
+    def _base64url_encode(data: bytes) -> str:
+        return base64.urlsafe_b64encode(data).decode("utf-8").replace("=", "")
 
     @staticmethod
-    def _valid_uuid(
-        uuid: str
-    ) -> bool:
-        uuid4hex = re.compile(r'^[a-f0-9]{8}-?[a-f0-9]{4}-?4[a-f0-9]{3}-?[89ab][a-f0-9]{3}-?[a-f0-9]{12}', re.I)
+    def _valid_uuid(uuid: str) -> bool:
+        uuid4hex = re.compile(
+            r"^[a-f0-9]{8}-?[a-f0-9]{4}-?4[a-f0-9]{3}-?[89ab][a-f0-9]{3}-?[a-f0-9]{12}",
+            re.I,
+        )
         match = uuid4hex.match(uuid)
         return bool(match)
